package com.FranckBarbier.New_York_City_Penitentiary.services;

@org.springframework.web.bind.annotation.RestController
@org.springframework.web.bind.annotation.RequestMapping(value = "/motives")
public class MotiveCRUD implements JSON_service {

    @org.springframework.beans.factory.annotation.Autowired
    private com.FranckBarbier.New_York_City_Penitentiary.persistence.MotiveDao _motiveDao;

    @Override
    public String to_JSON(QUERY type) {
        java.util.List<com.FranckBarbier.New_York_City_Penitentiary.persistence.Motive> motives
                = type == QUERY.ALL_MOTIVES ? _motiveDao.findAll() : new java.util.LinkedList<>();
        javax.json.JsonArrayBuilder _motives = javax.json.Json.createArrayBuilder();
        for (com.FranckBarbier.New_York_City_Penitentiary.persistence.Motive motive : motives) {
            javax.json.JsonObjectBuilder builder = javax.json.Json.createObjectBuilder();
            builder.add("MOTIVE_LABEL", motive.get_motive_label());
            _motives.add(builder.build());
        }
        return _motives.build().toString();
    }

    @org.springframework.web.bind.annotation.GetMapping(value = "")
    public String all() {
        return to_JSON(QUERY.ALL_MOTIVES);
    }

    @org.springframework.web.bind.annotation.GetMapping(value = "/{motive_number}")
    public String get(@org.springframework.web.bind.annotation.PathVariable String motive_number) {
        java.util.Optional<com.FranckBarbier.New_York_City_Penitentiary.persistence.Motive> motive = _motiveDao.findById(motive_number);
        javax.json.JsonObjectBuilder builder = javax.json.Json.createObjectBuilder();
        if (motive.isPresent()) {
            builder.add("MOTIVE_LABEL", motive.get().get_motive_label());
        }
        return builder.build().toString();
    }

    // https://howtodoinjava.com/spring5/webmvc/controller-getmapping-postmapping/
    // https://linuxize.com/post/curl-post-request/
    // curl -X POST -H "Content-Type: application/json" -d '{"_motive_number":"02", "_motive_label":"assault and battery"}' http://localhost:8080/NYCP/API/motives
    @org.springframework.web.bind.annotation.PostMapping(value = "", // <=> '@RequestMapping(method = RequestMethod.POST)'
            consumes = org.springframework.http.MediaType.APPLICATION_JSON_VALUE)
    public org.springframework.hateoas.RepresentationModel<com.FranckBarbier.New_York_City_Penitentiary.persistence.Motive> post(@org.springframework.web.bind.annotation.RequestBody com.FranckBarbier.New_York_City_Penitentiary.persistence.Motive motive) {
        _motiveDao.save(motive);
        // 'linkTo' inspects the controller class and obtains its root mapping, e.g., http://localhost:8080/NYCP/API/motives
        // 'slash' adds 'motive_number' as the path variable of the link
        // finally, 'withSelfRel' qualifies the relation as a self-link
        org.springframework.hateoas.Link link
                = org.springframework.hateoas.server.mvc.WebMvcLinkBuilder.linkTo(MotiveCRUD.class).slash(motive.get_motive_number()).withSelfRel();
        // System.out.println(link.toUri().toString()); // e.g., http://localhost:8080/NYCP/API/motives/02
        motive.add(link);
        return motive;
    }

    // curl -X POST -d 'motive_number=02&motive_label=assault and battery' http://localhost:8080/NYCP/API/motives/new
    @org.springframework.web.bind.annotation.PostMapping(value = "/new") // <=> '@RequestMapping(method = RequestMethod.POST)'
    public void post_(@org.springframework.web.bind.annotation.RequestParam java.util.Map<String, String> query) {
        com.FranckBarbier.New_York_City_Penitentiary.persistence.Motive motive = new com.FranckBarbier.New_York_City_Penitentiary.persistence.Motive();
        motive.set_motive_number(query.get("motive_number"));
        motive.set_motive_label(query.get("motive_label"));
        _motiveDao.save(motive);
    }

    @org.springframework.web.bind.annotation.PutMapping(value = "/renew")
    public void put(@org.springframework.web.bind.annotation.RequestBody com.FranckBarbier.New_York_City_Penitentiary.persistence.Motive motive) {
        _motiveDao.save(motive);
    }

    @org.springframework.web.bind.annotation.DeleteMapping(value = "/{motive_number}")
    public void delete(@org.springframework.web.bind.annotation.PathVariable String motive_number) {
        _motiveDao.deleteById(motive_number);
    }
}
